Index: src/gpu/SkGpuDevice.cpp |
diff --git a/src/gpu/SkGpuDevice.cpp b/src/gpu/SkGpuDevice.cpp |
index b719f84278d35dca18398d756aef313531c9527e..0ec2b858c43c23bbaab8ee7741345c3c33e096df 100644 |
--- a/src/gpu/SkGpuDevice.cpp |
+++ b/src/gpu/SkGpuDevice.cpp |
@@ -1765,9 +1765,9 @@ bool SkGpuDevice::filterTextFlags(const SkPaint& paint, TextFlags* flags) { |
paint.getPathEffect() || |
paint.isFakeBoldText() || |
paint.getStyle() != SkPaint::kFill_Style) { |
// turn off lcd |
flags->fFlags = paint.getFlags() & ~SkPaint::kLCDRenderText_Flag; |
- flags->fHinting = paint.getHinting(); |
+ flags->fFlags |= SkPaint::kGenA8FromLCD_Flag; |
return true; |
} |
// we're cool with the paint as is |
@@ -1765,9 +1765,9 @@ bool SkGpuDevice::filterTextFlags(const SkPaint& paint, TextFlags* flags) { |
paint.isFakeBoldText() || |
paint.getStyle() != SkPaint::kFill_Style) { |
- // turn off lcd |
+ // turn off lcd, but turn on kGenA8 |
flags->fFlags = paint.getFlags() & ~SkPaint::kLCDRenderText_Flag; |